==> qtjambi-qt3dcore-5.15.14-sources.jar: io/qt/qt3d/core/QStaticPropertyUpdatedChangeBase.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>The base class for all static PropertyUpdated QSceneChange events</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyupdatedchangebase.html">Qt3DCore::QStaticPropertyUpdatedChangeBase</a></p>
 */
public class QStaticPropertyUpdatedChangeBase extends io.qt.qt3d.core.QPropertyUpdatedChangeBase
{
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyupdatedchangebase.html#QStaticPropertyUpdatedChangeBase">Qt3DCore::QStaticPropertyUpdatedChangeBase::QStaticPropertyUpdatedChangeBase(Qt3DCore::QNodeId)</a></p>
     */
    @Deprecated
    protected QStaticPropertyUpdatedChangeBase(io.qt.qt3d.core.@NonNull QNodeId subjectId){
        super((QPrivateConstructor)null);
        initialize_native(this, subjectId);
    }
    
    @Deprecated
    private native static void initialize_native(QStaticPropertyUpdatedChangeBase instance, io.qt.qt3d.core.QNodeId subjectId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyupdatedchangebase.html#propertyName">Qt3DCore::QStaticPropertyUpdatedChangeBase::propertyName()const</a></p>
     */
    @QtUninvokable
    public final java.lang.@Nullable String propertyName(){
        return propertyName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String propertyName_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyupdatedchangebase.html#setPropertyName">Qt3DCore::QStaticPropertyUpdatedChangeBase::setPropertyName(const char*)</a></p>
     */
    @QtUninvokable
    public final void setPropertyName(java.lang.@Nullable String name){
        setPropertyName_native_const_char_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @QtUninvokable
    private native void setPropertyName_native_const_char_ptr(long __this__nativeId, java.lang.String name);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @NativeAccess
    protected QStaticPropertyUpdatedChangeBase(QPrivateConstructor p) { super(p); } 
    
}

==> qtjambi-qt3dcore-5.15.19-sources.jar: io/qt/qt3d/core/QStaticPropertyUpdatedChangeBase.java <==
package io.qt.qt3d.core;

import io.qt.*;


/**
 * <p>The base class for all static PropertyUpdated QSceneChange events</p>
 * <p>Java wrapper for Qt class <code><a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyupdatedchangebase.html">Qt3DCore::QStaticPropertyUpdatedChangeBase</a></code></p>
 */
public class QStaticPropertyUpdatedChangeBase extends io.qt.qt3d.core.QPropertyUpdatedChangeBase
{
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyupdatedchangebase.html#QStaticPropertyUpdatedChangeBase">Qt3DCore::QStaticPropertyUpdatedChangeBase::<wbr/>QStaticPropertyUpdatedChangeBase(Qt3DCore::QNodeId)</a></code></p>
     */
    protected QStaticPropertyUpdatedChangeBase(io.qt.qt3d.core.@NonNull QNodeId subjectId){
        super((QPrivateConstructor)null);
        initialize_native(this, subjectId);
    }
    
    private native static void initialize_native(QStaticPropertyUpdatedChangeBase instance, io.qt.qt3d.core.QNodeId subjectId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyupdatedchangebase.html#propertyName">Qt3DCore::QStaticPropertyUpdatedChangeBase::<wbr/>propertyName()const</a></code></p>
     */
    @QtUninvokable
    public final java.lang.@Nullable String propertyName(){
        return propertyName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native java.lang.String propertyName_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code><a href="http://doc.qt.io/qt-5/qt3dcore-qstaticpropertyupdatedchangebase.html#setPropertyName">Qt3DCore::QStaticPropertyUpdatedChangeBase::<wbr/>setPropertyName(const char*)</a></code></p>
     */
    @QtUninvokable
    public final void setPropertyName(java.lang.@Nullable String name){
        setPropertyName_native_const_char_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), name);
    }
    
    @QtUninvokable
    private native void setPropertyName_native_const_char_ptr(long __this__nativeId, java.lang.String name);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QStaticPropertyUpdatedChangeBase(QPrivateConstructor p) { super(p); } 
    
}
